@@ -140,7 +140,7 @@ def compile_macros():
 @click.option('-i', '--input_config_path', default=None, help='Path to json file containing input workspace paths')
 @click.option('-b', '--base_path', default='./', help='Base path for input config')
 @click.option('-o', '--outfile', default='renamed_np.json', help='Output filename')
-def harmonize_np(ws_files, reference, input_list, base_path, outfile):
+def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
     """
     Harmonize NP names across different workspaces
     """
@@ -151,4 +151,4 @@ def harmonize_np(ws_files, reference, input_list, base_path, outfile):
     if len(ws_files) > 0:
         harmonizer.harmonize(ws_files, outfile=outfile)
     elif (input_list is not None):
-        harmonizer.harmonize_multi_input(input_list, base_path, outfile=outfile) 
\ No newline at end of file
+        harmonizer.harmonize_multi_input(input_config_path, base_path, outfile=outfile) 
\ No newline at end of file
